# Contributing

Please check out the [good first issue][good first issue] label for tasks,
that are good candidates for your first contribution to
**pytest-snail**. Your contributions are greatly
appreciated! Every little bit helps, and credit will always be given!

You can also support the development of this project by volunteering to
become a maintainer, which means you will be able to triage issues, merge
pull-requests, and publish new releases. If you're interested, please submit
a pull-request to add yourself to the list of [maintainers][community] and
we'll get you started! 🚀

Please note that **pytest-snail** is released with a
[Contributor Code of Conduct][code-of-conduct]. By participating in this
project you agree to abide by its terms.

[good first issue]: https://github.com/hackebrot/pytest-snail/labels/good%20first%20issue
[code-of-conduct]: https://github.com/hackebrot/pytest-snail/blob/master/CODE_OF_CONDUCT.md
[community]: https://github.com/hackebrot/pytest-snail/blob/master/COMMUNITY.md
